#
# spec file for package mozilla-nspr
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#               2006-2011 Wolfgang Rosenauer
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           mozilla-nspr
BuildRequires:  gcc-c++ pkg-config
License:        MPLv1.1 or GPLv2+ or LGPLv2.1+
Version:        4.8.9
Release:        1.3.1
Summary:        Netscape Portable Runtime
Url:            http://www.mozilla.org/projects/nspr/
# bug437293
%ifarch ppc64
Obsoletes:      mozilla-nspr-64bit
%endif
#
Group:          System/Libraries
Source:         ftp://ftp.mozilla.org/pub/nspr/releases/v%{version}/src/nspr-%{version}.tar.bz2
Source1:        baselibs.conf
Patch3:         pkgconfig.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
NSPR provides platform independence for non-GUI operating system
facilities. These facilities include threads, thread synchronization,
normal file and network I/O, interval timing and calendar time, basic
memory management (malloc and free), and shared library linking.


%package devel
License:        MPLv1.1 or GPLv2+ or LGPLv2.1+
Summary:        Netscape Portable Runtime development files
Group:          Development/Libraries/Other
Requires:       mozilla-nspr = %{version}
# bug437293
%ifarch ppc64
Obsoletes:      mozilla-nspr-devel-64bit
%endif
#

%description devel
NSPR provides platform independence for non-GUI operating system
facilities. These facilities include threads, thread synchronization,
normal file and network I/O, interval timing and calendar time, basic
memory management (malloc and free), and shared library linking.


%prep
%setup -n nspr-%{version} -q
cd mozilla
%patch3 -p2

%build
cd mozilla/nsprpub
export CFLAGS="$RPM_OPT_FLAGS"
./configure --enable-optimize="$CFLAGS" \
            --disable-debug \
%ifarch x86_64
	    --enable-64bit \
%endif
	    --libdir=%{_libdir} \
	    --includedir=%{_includedir}/nspr4 \
	    --prefix=%{_prefix}
make %{?jobs:-j%jobs}

%install
mkdir -p $RPM_BUILD_ROOT%{_bindir}
mkdir -p $RPM_BUILD_ROOT%{_libdir}/nspr
mkdir -p $RPM_BUILD_ROOT%{_libdir}/pkgconfig
mkdir -p $RPM_BUILD_ROOT%{_includedir}/nspr4
cp mozilla/nsprpub/config/nspr-config $RPM_BUILD_ROOT%{_bindir}/
cp mozilla/nsprpub/config/nspr.pc $RPM_BUILD_ROOT/%{_libdir}/pkgconfig
cp -L mozilla/nsprpub/dist/lib/*.so $RPM_BUILD_ROOT/%{_libdir}
cp -L mozilla/nsprpub/dist/lib/*.a  $RPM_BUILD_ROOT/%{_libdir}/nspr/
cp -rL mozilla/nsprpub/dist/include/nspr/* $RPM_BUILD_ROOT/%{_includedir}/nspr4/
# #31667
chmod -x $RPM_BUILD_ROOT/%{_includedir}/nspr4/prvrsion.h

%clean
rm -rf $RPM_BUILD_ROOT

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%{_libdir}/*.so

%files devel
%defattr(-, root, root)
%{_bindir}/nspr-config
%{_libdir}/pkgconfig/nspr.pc
%{_includedir}/nspr4/
%exclude %{_includedir}/nspr4/md/*
%{_libdir}/nspr/

%changelog
* Fri Aug 12 2011 wr@rosenauer.org
- update to 4.8.9 RTM
  * no release notes available from upstream
* Thu May 19 2011 wr@rosenauer.org
- update to 4.8.8 RTM
  * minor cleanup changes
  * minor changes not affecting the Linux platform
* Thu Apr 28 2011 wr@rosenauer.org
- update to 4.8.8beta3
  * support IPv6 on Android (bmo#626866)
  * use AI_ADDRCONFIG for loopback hostnames (bmo#614526)
  * support SDP sockets (bmo#518078)
  * support m32r architecture (bmo#635667)
  * use atomic functions on ARM (bmo#626309)
  * some other fixes not affecting the Linux platform
* Sun Jan  9 2011 wr@rosenauer.org
- update to 4.8.7 RTM
  * no code changes to beta2
  * only updated internal version information
* Thu Dec  9 2010 wr@rosenauer.org
- update to 4.8.7beta2
  * minimal requirement for NSS 3.12.9
  * bugfixes
* Fri Jul 23 2010 wr@rosenauer.org
- update to 4.8.6
  * moved PR_STATIC_ASSERT from prlog.h to prtypes.h
  * use new NSPR atomic macros
  * bugfixes
- removed fixes for temporary package split
* Sat Apr 24 2010 coolo@novell.com
- buildrequire pkg-config to fix provides
* Fri Mar  5 2010 wr@rosenauer.org
- update to 4.8.4
  * bugfix release
* Fri Dec 18 2009 wr@rosenauer.org
- update to 4.8.3
  * NSPR logging timestamp month number is off by one
  * fixed possible DoS in prdtoa
- added baselibs.conf
* Tue Oct 13 2009 wr@rosenauer.org
- update to 4.8.2 (bnc#546371)
  * RISC OS, Symbian and WinCE improvements
  * bugfixes and optimizations
* Wed May 20 2009 wr@rosenauer.org
- update to 4.8
  * Windows 9x and NT 3.51 and 4.0 are no longer
    supported
  * Windows Mobile and Mac OS X 64-bit (x86_64) are now supported
  * New macros:
    prlock.h: PR_ASSERT_CURRENT_THREAD_OWNS_LOCK
    prmon.h: PR_ASSERT_CURRENT_THREAD_IN_MONITOR
  * special log module timestamp adds timestamps to NSPR log
    messages
* Sat Apr 11 2009 wr@rosenauer.org
- update to 4.7.4
  * Fix strict aliasing issues in prdtoa.c for gcc 4.4 (bmo#439144)
  - obsoletes prdtoa.patch and -fno-strict-aliasing flag
  * In prlink.c, errStrBuf is not thread-safe
* Fri Jan 30 2009 hfiguiere@suse.de
- update to 4.7.3
  * Only Solaris fixes.
* Tue Jan 13 2009 wr@rosenauer.org
- update to 4.7.2 RTM version
  * use /dev/urandom instead of /dev/random (bmo#455829)
  * support Linux/SPARC64 (bmo#459304)
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Wed Jun 18 2008 maw@suse.de
- Merge changes from the build service (thanks, Wolfgang)
  (bnc#400001 and SWAMP#18164).
* Fri May  2 2008 wr@rosenauer.org
- update to 4.7.1 RTM version
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Mon Mar 31 2008 maw@suse.de
- Undo the shared library package split, per discussion in
  opensuse-packaging.
* Wed Mar 26 2008 wr@rosenauer.org
- update to 4.7.1beta2-20080325 snapshot
* Tue Mar 25 2008 maw@suse.de
- Merge changes from the build service (thanks, Wolfgang)
- Update to the 4.7.1beta1-20080225 snapshot
- Split out a shared library subpackage.
* Thu Feb  7 2008 maw@suse.de
- Merge changes from the build service (thanks, Wolfgang).
- Remove strcstr.patch, which has been upstreamed.
* Thu Feb  7 2008 wr@rosenauer.org
- update to 4.7.0 (requirement for Firefox 3)
- added a %%clean section
* Thu Nov 22 2007 wr@rosenauer.org
- update to version 4.6.8
* Mon Jun 11 2007 ro@suse.de
- update to NSPR 4.6.7 (pull in from wr from opensuse BS)
* Wed Feb 21 2007 maw@suse.de
- Update to version 4.6.5
* Wed Feb  7 2007 wr@rosenauer.org
- fixed crasher in PL_strcaserstr() (strcstr.patch) (bmo #369467)
* Wed Jan 31 2007 maw@suse.de
- Don't install %%{_includedir}/nspr4/prvrsion.h with the executable
  bit set.
* Sat Oct 21 2006 aj@suse.de
- from openSUSE BuildService (thanks Wolfgang Rosenauer):
- update to version 4.6.3: Bug fix release.
* Tue Aug  1 2006 stark@suse.de
- version is still 4.6.2
* Sat Jul 15 2006 stark@suse.de
- added PR_SI_HOSTNAME_UNTRUNCATED flag to get the hostname as
  FQDN with PR_GetSystemInfo() if configured on a system
  (bmo #322956)
* Mon May 15 2006 stark@suse.de
- update to 4.6.2 RTM version
  bugs fixed:
  * PR_ParseTimeString use PR_Assert and it calls abort on
    invalid date (bmo #247896)
  * PR_SetSysfdTableSize and PR_GetSysfdTableMax are not exported
    (bmo #326110)
  * Add a UTF-16 API to load a library (bmo #326168)
  * various changes for non-Linux platforms
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 16 2005 stark@suse.de
- update to final 4.6.1 RTM version
* Wed Dec  7 2005 stark@suse.de
- moved headers to nspr4 sub-directories and removed some
  unneeded headers
* Fri Nov 25 2005 stark@suse.de
- changed ldconfig call in install-scripts
* Tue Nov 15 2005 stark@suse.de
- current 4.6.1pre (20051114)
* Tue Oct 11 2005 stark@suse.de
- next official release will most likely be 4.6.1 (20051010)
* Mon Sep 26 2005 mls@suse.de
- make devel package require base package
* Thu Sep 22 2005 stark@suse.de
- update to 4.7.0pre (20050921)
* Tue May 31 2005 stark@suse.de
- update to final 4.6
* Thu May 19 2005 stark@suse.de
- renamed mozilla-nspr.pc to nspr.pc as decided upstream
- latest snapshots which integrates hidden.patch
* Wed May 18 2005 stark@suse.de
- workaround for gcc bug (bmo #293438, bnc #83908)
- provide its own pkgconfig file (mozilla-nspr.pc)
* Tue May 10 2005 stark@suse.de
- update to current HEAD (upstreamed two patches)
* Tue Apr 26 2005 stark@suse.de
- moved static libs to sub-directory
  (almost nobody should link against them statically)
* Mon Apr 25 2005 stark@suse.de
- fix nspr-config for biarch
* Tue Mar 22 2005 stark@suse.de
- update to HEAD for mozilla compatibility
* Sat Mar 19 2005 stark@suse.de
- update to 4.5.2beta1
* Tue Mar  8 2005 stark@suse.de
- initial standalone package
